"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBalance = exports.signAndSendTransaction = exports.createDefaultTransaction = exports.fundWalletWithSol = exports.generateKeyPairSignerWithSol = exports.createKeyPairSigner = exports.createDefaultSolanaClient = void 0;
/* eslint-disable import/no-extraneous-dependencies */
require("@solana/webcrypto-ed25519-polyfill");
const signers_1 = require("@solana/signers");
const web3_js_1 = require("@solana/web3.js");
const createDefaultSolanaClient = () => {
    const rpc = (0, web3_js_1.createSolanaRpc)('http://127.0.0.1:8899');
    const rpcSubscriptions = (0, web3_js_1.createSolanaRpcSubscriptions)('ws://127.0.0.1:8900');
    return { rpc, rpcSubscriptions };
};
exports.createDefaultSolanaClient = createDefaultSolanaClient;
const createKeyPairSigner = async (bytes) => {
    const publicKeyBytes = bytes.slice(32);
    const privateKeyBytes = bytes.slice(0, 32);
    const [publicKey, privateKey] = await Promise.all([
        crypto.subtle.importKey('raw', publicKeyBytes, 'Ed25519', true, ['verify']),
        (0, web3_js_1.createPrivateKeyFromBytes)(privateKeyBytes),
    ]);
    return (0, signers_1.createSignerFromKeyPair)({ privateKey, publicKey });
};
exports.createKeyPairSigner = createKeyPairSigner;
const generateKeyPairSignerWithSol = async (client, putativeLamports = 1000000000n) => {
    //   const airdropRequester = createDefaultAirdropRequester(client);
    const signer = await (0, signers_1.generateKeyPairSigner)();
    client.rpc.requestAirdrop(signer.address, (0, web3_js_1.lamports)(putativeLamports), {
        commitment: 'confirmed',
    });
    return signer;
};
exports.generateKeyPairSignerWithSol = generateKeyPairSignerWithSol;
const fundWalletWithSol = async (client, address, putativeLamports = 1000000000n) => {
    client.rpc.requestAirdrop(address, (0, web3_js_1.lamports)(putativeLamports), {
        commitment: 'confirmed',
    });
};
exports.fundWalletWithSol = fundWalletWithSol;
const createDefaultTransaction = async (client, feePayer) => {
    const { value: latestBlockhash } = await client.rpc
        .getLatestBlockhash()
        .send();
    return (0, web3_js_1.pipe)((0, web3_js_1.createTransaction)({ version: 0 }), (tx) => (0, web3_js_1.setTransactionFeePayer)(feePayer, tx), (tx) => (0, web3_js_1.setTransactionLifetimeUsingBlockhash)(latestBlockhash, tx));
};
exports.createDefaultTransaction = createDefaultTransaction;
const signAndSendTransaction = async (client, transaction, commitment = 'confirmed') => {
    const signedTransaction = await (0, signers_1.signTransactionWithSigners)(transaction);
    const signature = (0, web3_js_1.getSignatureFromTransaction)(signedTransaction);
    client.rpc.sendAndConfirmTransaction(signedTransaction, { commitment });
    return signature;
};
exports.signAndSendTransaction = signAndSendTransaction;
const getBalance = async (client, address) => (await client.rpc.getBalance(address, { commitment: 'confirmed' }).send())
    .value;
exports.getBalance = getBalance;
